declare module "react" {
  export type ReactNode = any;
  export type ReactElement<P=any,T=any> = any;
  export type ComponentType<P=any> = any;
  export type Component<P=any,S=any> = any;
  export type FC<P=any> = any;
  export type ElementType = any;
  export const Fragment: any;
  export const StrictMode: any;
  export function createElement(...a: any[]): any;
  export function isValidElement(o: any): boolean;
  const React: any; export default React; export = React;
}
declare namespace JSX { interface Element {} interface IntrinsicElements { [k:string]: any; } }
