declare module "pacote" {
  export type Manifest = any;
  export function packument(name: string): Promise<any>;
  export function manifest(name: string): Promise<any>;
  const _: any; export default _;
}
